nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Hccommandstatus

Struct Hccommandstatus 

#[repr(transparent)]
pub struct Hccommandstatus(pub u32);
This register is used to receive the commands from the Host Controller Driver (HCD)

Tuple Fields

0: u32

Implementations

Source

impl Hccommandstatus

pub const fn hcr(&self) -> bool

HostControllerReset This bit is set by HCD to initiate a software reset of HC.

pub const fn set_hcr(&mut self, val: bool)

HostControllerReset This bit is set by HCD to initiate a software reset of HC.

pub const fn clf(&self) -> bool

ControlListFilled This bit is used to indicate whether there are any TDs on the Control list.

pub const fn set_clf(&mut self, val: bool)

ControlListFilled This bit is used to indicate whether there are any TDs on the Control list.

pub const fn blf(&self) -> bool

BulkListFilled This bit is used to indicate whether there are any TDs on the Bulk list.

pub const fn set_blf(&mut self, val: bool)

BulkListFilled This bit is used to indicate whether there are any TDs on the Bulk list.

pub const fn ocr(&self) -> bool

OwnershipChangeRequest This bit is set by an OS HCD to request a change of control of the HC.

pub const fn set_ocr(&mut self, val: bool)

OwnershipChangeRequest This bit is set by an OS HCD to request a change of control of the HC.

pub const fn soc(&self) -> u8

SchedulingOverrunCount These bits are incremented on each scheduling overrun error.

pub const fn set_soc(&mut self, val: u8)

SchedulingOverrunCount These bits are incremented on each scheduling overrun error.