nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Hccontrol

Struct Hccontrol 

#[repr(transparent)]
pub struct Hccontrol(pub u32);
Defines the operating modes of the HC

Tuple Fields

0: u32

Implementations

Source

impl Hccontrol

pub const fn cbsr(&self) -> u8

ControlBulkServiceRatio.

pub const fn set_cbsr(&mut self, val: u8)

ControlBulkServiceRatio.

pub const fn ple(&self) -> bool

PeriodicListEnable.

pub const fn set_ple(&mut self, val: bool)

PeriodicListEnable.

pub const fn ie(&self) -> bool

IsochronousEnable.

pub const fn set_ie(&mut self, val: bool)

IsochronousEnable.

pub const fn cle(&self) -> bool

ControlListEnable.

pub const fn set_cle(&mut self, val: bool)

ControlListEnable.

pub const fn ble(&self) -> bool

BulkListEnable This bit is set to enable the processing of the Bulk list in the next Frame.

pub const fn set_ble(&mut self, val: bool)

BulkListEnable This bit is set to enable the processing of the Bulk list in the next Frame.

pub const fn hcfs(&self) -> u8

HostControllerFunctionalState for USB 00b: USBRESET 01b: USBRESUME 10b: USBOPERATIONAL 11b: USBSUSPEND A transition to USBOPERATIONAL from another state causes SOFgeneration to begin 1 ms later.

pub const fn set_hcfs(&mut self, val: u8)

HostControllerFunctionalState for USB 00b: USBRESET 01b: USBRESUME 10b: USBOPERATIONAL 11b: USBSUSPEND A transition to USBOPERATIONAL from another state causes SOFgeneration to begin 1 ms later.

pub const fn ir(&self) -> bool

InterruptRouting This bit determines the routing of interrupts generated by events registered in HcInterruptStatus.

pub const fn set_ir(&mut self, val: bool)

InterruptRouting This bit determines the routing of interrupts generated by events registered in HcInterruptStatus.

pub const fn rwc(&self) -> bool

RemoteWakeupConnected This bit indicates whether HC supports remote wake-up signaling.

pub const fn set_rwc(&mut self, val: bool)

RemoteWakeupConnected This bit indicates whether HC supports remote wake-up signaling.

pub const fn rwe(&self) -> bool

RemoteWakeupEnable This bit is used by HCD to enable or disable the remote wake-up feature upon the detection of upstream resume signaling.

pub const fn set_rwe(&mut self, val: bool)

RemoteWakeupEnable This bit is used by HCD to enable or disable the remote wake-up feature upon the detection of upstream resume signaling.