nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Hcfminterval

Struct Hcfminterval 

#[repr(transparent)]
pub struct Hcfminterval(pub u32);
Defines the bit time interval in a frame and the full speed maximum packet size which would not cause an overrun

Tuple Fields

0: u32

Implementations

Source

impl Hcfminterval

pub const fn fi(&self) -> u16

FrameInterval This specifies the interval between two consecutive SOFs in bit times.

pub const fn set_fi(&mut self, val: u16)

FrameInterval This specifies the interval between two consecutive SOFs in bit times.

pub const fn fsmps(&self) -> u16

FSLargestDataPacket This field specifies a value which is loaded into the Largest Data Packet Counter at the beginning of each frame.

pub const fn set_fsmps(&mut self, val: u16)

FSLargestDataPacket This field specifies a value which is loaded into the Largest Data Packet Counter at the beginning of each frame.

pub const fn fit(&self) -> bool

FrameIntervalToggle HCD toggles this bit whenever it loads a new value to FrameInterval.

pub const fn set_fit(&mut self, val: bool)

FrameIntervalToggle HCD toggles this bit whenever it loads a new value to FrameInterval.