nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Hcinterruptdisable

Struct Hcinterruptdisable 

#[repr(transparent)]
pub struct Hcinterruptdisable(pub u32);
The bits in this register are used to disable corresponding bits in the HCInterruptStatus register and in turn disable that event leading to hardware interrupt

Tuple Fields

0: u32

Implementations

Source

impl Hcinterruptdisable

pub const fn so(&self) -> bool

Scheduling Overrun interrupt.

pub const fn set_so(&mut self, val: bool)

Scheduling Overrun interrupt.

pub const fn wdh(&self) -> bool

HcDoneHead Writeback interrupt.

pub const fn set_wdh(&mut self, val: bool)

HcDoneHead Writeback interrupt.

pub const fn sf(&self) -> bool

Start of Frame interrupt.

pub const fn set_sf(&mut self, val: bool)

Start of Frame interrupt.

pub const fn rd(&self) -> bool

Resume Detect interrupt.

pub const fn set_rd(&mut self, val: bool)

Resume Detect interrupt.

pub const fn ue(&self) -> bool

Unrecoverable Error interrupt.

pub const fn set_ue(&mut self, val: bool)

Unrecoverable Error interrupt.

pub const fn fno(&self) -> bool

Frame Number Overflow interrupt.

pub const fn set_fno(&mut self, val: bool)

Frame Number Overflow interrupt.

pub const fn rhsc(&self) -> bool

Root Hub Status Change interrupt.

pub const fn set_rhsc(&mut self, val: bool)

Root Hub Status Change interrupt.

pub const fn oc(&self) -> bool

Ownership Change interrupt.

pub const fn set_oc(&mut self, val: bool)

Ownership Change interrupt.

pub const fn mie(&self) -> bool

A 0 written to this field is ignored by HC.

pub const fn set_mie(&mut self, val: bool)

A 0 written to this field is ignored by HC.