nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Hcperiodcurrented

Struct Hcperiodcurrented 

#[repr(transparent)]
pub struct Hcperiodcurrented(pub u32);
Contains the physical address of the current isochronous or interrupt endpoint descriptor

Tuple Fields

0: u32

Implementations

Source

impl Hcperiodcurrented

pub const fn pced(&self) -> u32

The content of this register is updated by HC after a periodic ED is processed.

pub const fn set_pced(&mut self, val: u32)

The content of this register is updated by HC after a periodic ED is processed.