nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Hcperiodicstart

Struct Hcperiodicstart 

#[repr(transparent)]
pub struct Hcperiodicstart(pub u32);
Contains a programmable 14-bit value which determines the earliest time HC should start processing a periodic list

Tuple Fields

0: u32

Implementations

Source

impl Hcperiodicstart

pub const fn ps(&self) -> u16

PeriodicStart After a hardware reset, this field is cleared and then set by HCD during the HC initialization.

pub const fn set_ps(&mut self, val: u16)

PeriodicStart After a hardware reset, this field is cleared and then set by HCD during the HC initialization.