nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Hcrhdescriptora

Struct Hcrhdescriptora 

#[repr(transparent)]
pub struct Hcrhdescriptora(pub u32);
First of the two registers which describes the characteristics of the root hub

Tuple Fields

0: u32

Implementations

Source

impl Hcrhdescriptora

pub const fn ndp(&self) -> u8

NumberDownstreamPorts These bits specify the number of downstream ports supported by the root hub.

pub const fn set_ndp(&mut self, val: u8)

NumberDownstreamPorts These bits specify the number of downstream ports supported by the root hub.

pub const fn psm(&self) -> bool

PowerSwitchingMode This bit is used to specify how the power switching of the root hub ports is controlled.

pub const fn set_psm(&mut self, val: bool)

PowerSwitchingMode This bit is used to specify how the power switching of the root hub ports is controlled.

pub const fn nps(&self) -> bool

NoPowerSwitching These bits are used to specify whether power switching is supported or port are always powered.

pub const fn set_nps(&mut self, val: bool)

NoPowerSwitching These bits are used to specify whether power switching is supported or port are always powered.

pub const fn dt(&self) -> bool

DeviceType This bit specifies that the root hub is not a compound device.

pub const fn set_dt(&mut self, val: bool)

DeviceType This bit specifies that the root hub is not a compound device.

pub const fn ocpm(&self) -> bool

OverCurrentProtectionMode This bit describes how the overcurrent status for the root hub ports are reported.

pub const fn set_ocpm(&mut self, val: bool)

OverCurrentProtectionMode This bit describes how the overcurrent status for the root hub ports are reported.

pub const fn nocp(&self) -> bool

NoOverCurrentProtection This bit describes how the overcurrent status for the root hub ports are reported.

pub const fn set_nocp(&mut self, val: bool)

NoOverCurrentProtection This bit describes how the overcurrent status for the root hub ports are reported.

pub const fn potpgt(&self) -> u8

PowerOnToPowerGoodTime This byte specifies the duration the HCD has to wait before accessing a powered-on port of the root hub.

pub const fn set_potpgt(&mut self, val: u8)

PowerOnToPowerGoodTime This byte specifies the duration the HCD has to wait before accessing a powered-on port of the root hub.