nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Hcrhdescriptorb

Struct Hcrhdescriptorb 

#[repr(transparent)]
pub struct Hcrhdescriptorb(pub u32);
Second of the two registers which describes the characteristics of the Root Hub

Tuple Fields

0: u32

Implementations

Source

impl Hcrhdescriptorb

pub const fn dr(&self) -> u16

DeviceRemovable Each bit is dedicated to a port of the Root Hub.

pub const fn set_dr(&mut self, val: u16)

DeviceRemovable Each bit is dedicated to a port of the Root Hub.

pub const fn ppcm(&self) -> u16

PortPowerControlMask Each bit indicates if a port is affected by a global power control command when PowerSwitchingMode is set.

pub const fn set_ppcm(&mut self, val: u16)

PortPowerControlMask Each bit indicates if a port is affected by a global power control command when PowerSwitchingMode is set.