#[repr(transparent)]pub struct Hccommandstatus(pub u32);Expand description
This register is used to receive the commands from the Host Controller Driver (HCD)
Tuple Fields
0: u32Implementations
Sourceimpl Hccommandstatus
impl Hccommandstatus
Sourcepub const fn hcr(&self) -> bool
pub const fn hcr(&self) -> bool
HostControllerReset This bit is set by HCD to initiate a software reset of HC.
Sourcepub const fn set_hcr(&mut self, val: bool)
pub const fn set_hcr(&mut self, val: bool)
HostControllerReset This bit is set by HCD to initiate a software reset of HC.
Sourcepub const fn clf(&self) -> bool
pub const fn clf(&self) -> bool
ControlListFilled This bit is used to indicate whether there are any TDs on the Control list.
Sourcepub const fn set_clf(&mut self, val: bool)
pub const fn set_clf(&mut self, val: bool)
ControlListFilled This bit is used to indicate whether there are any TDs on the Control list.
Sourcepub const fn blf(&self) -> bool
pub const fn blf(&self) -> bool
BulkListFilled This bit is used to indicate whether there are any TDs on the Bulk list.
Sourcepub const fn set_blf(&mut self, val: bool)
pub const fn set_blf(&mut self, val: bool)
BulkListFilled This bit is used to indicate whether there are any TDs on the Bulk list.
Sourcepub const fn ocr(&self) -> bool
pub const fn ocr(&self) -> bool
OwnershipChangeRequest This bit is set by an OS HCD to request a change of control of the HC.
Sourcepub const fn set_ocr(&mut self, val: bool)
pub const fn set_ocr(&mut self, val: bool)
OwnershipChangeRequest This bit is set by an OS HCD to request a change of control of the HC.