#[repr(transparent)]pub struct Hccontrol(pub u32);Expand description
Defines the operating modes of the HC
Tuple Fields
0: u32Implementations
Sourceimpl Hccontrol
impl Hccontrol
Sourcepub const fn ble(&self) -> bool
pub const fn ble(&self) -> bool
BulkListEnable This bit is set to enable the processing of the Bulk list in the next Frame.
Sourcepub const fn set_ble(&mut self, val: bool)
pub const fn set_ble(&mut self, val: bool)
BulkListEnable This bit is set to enable the processing of the Bulk list in the next Frame.
Sourcepub const fn hcfs(&self) -> u8
pub const fn hcfs(&self) -> u8
HostControllerFunctionalState for USB 00b: USBRESET 01b: USBRESUME 10b: USBOPERATIONAL 11b: USBSUSPEND A transition to USBOPERATIONAL from another state causes SOFgeneration to begin 1 ms later.
Sourcepub const fn set_hcfs(&mut self, val: u8)
pub const fn set_hcfs(&mut self, val: u8)
HostControllerFunctionalState for USB 00b: USBRESET 01b: USBRESUME 10b: USBOPERATIONAL 11b: USBSUSPEND A transition to USBOPERATIONAL from another state causes SOFgeneration to begin 1 ms later.
Sourcepub const fn ir(&self) -> bool
pub const fn ir(&self) -> bool
InterruptRouting This bit determines the routing of interrupts generated by events registered in HcInterruptStatus.
Sourcepub const fn set_ir(&mut self, val: bool)
pub const fn set_ir(&mut self, val: bool)
InterruptRouting This bit determines the routing of interrupts generated by events registered in HcInterruptStatus.
Sourcepub const fn rwc(&self) -> bool
pub const fn rwc(&self) -> bool
RemoteWakeupConnected This bit indicates whether HC supports remote wake-up signaling.
Sourcepub const fn set_rwc(&mut self, val: bool)
pub const fn set_rwc(&mut self, val: bool)
RemoteWakeupConnected This bit indicates whether HC supports remote wake-up signaling.