#[repr(transparent)]pub struct Hcfminterval(pub u32);Expand description
Defines the bit time interval in a frame and the full speed maximum packet size which would not cause an overrun
Tuple Fields
0: u32Implementations
Sourceimpl Hcfminterval
impl Hcfminterval
Sourcepub const fn fi(&self) -> u16
pub const fn fi(&self) -> u16
FrameInterval This specifies the interval between two consecutive SOFs in bit times.
Sourcepub const fn set_fi(&mut self, val: u16)
pub const fn set_fi(&mut self, val: u16)
FrameInterval This specifies the interval between two consecutive SOFs in bit times.
Sourcepub const fn fsmps(&self) -> u16
pub const fn fsmps(&self) -> u16
FSLargestDataPacket This field specifies a value which is loaded into the Largest Data Packet Counter at the beginning of each frame.
Sourcepub const fn set_fsmps(&mut self, val: u16)
pub const fn set_fsmps(&mut self, val: u16)
FSLargestDataPacket This field specifies a value which is loaded into the Largest Data Packet Counter at the beginning of each frame.